PAWpySeed: pawpyseed.analysis.defect_composition Namespace Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Namespace Members

Classes | Functions
pawpyseed.analysis.defect_composition Namespace Reference

## Classes
class | BasisExpansion
class | BulkCharacter
class | PawpyData

## Functions
def | pycdt_dirs (top_dir)

## Function Documentation

def pawpyseed.analysis.defect_composition.pycdt_dirs | ( |  | top_dir | ) |